monthy_income = int( input (" What is your monthly Income ? " )) # $5000
spent_on_rent = int( input (" How much spent on rent ? " ))       #  $1000
groceries  =  int( input (" How much spent on groceries ? " ))    # $500
money_left_over = monthy_income - spent_on_rent - groceries 
print(monthy_income)
print(spent_on_rent)
print(groceries)
print(money_left_over)